@@ -7,11 +7,11 @@
 #include "simplefavoritesmodel.h"
 #include "actionlist.h"
 #include "appentry.h"
-#include "contactentry.h"
 #include "fileentry.h"
 #include "systementry.h"
 
 #include <KLocalizedString>
+#include <KStringHandler>
 
 SimpleFavoritesModel::SimpleFavoritesModel(QObject *parent)
     : AbstractModel(parent)
@@ -56,9 +56,11 @@ QVariant SimpleFavoritesModel::data(const QModelIndex &index, int role) const
     // TODO: Use a Switch for Enums.
     if (role == Qt::DisplayRole) {
         return entry->name();
+    } else if (role == Kicker::DisplayWrappedRole) {
+        return KStringHandler::preProcessWrap(entry->name());
     } else if (role == Qt::DecorationRole) {
-        if (!entry->icon().name().isEmpty())
-            return entry->icon().name();
+        if (!entry->icon().isEmpty())
+            return entry->icon();
         else
             return entry->icon();
     } else if (role == Kicker::DescriptionRole) {
@@ -312,8 +314,6 @@ AbstractEntry *SimpleFavoritesModel::favoriteFromId(const QString &id)
 
     if ((s.isEmpty() && id.contains(QLatin1String(".desktop"))) || s == QLatin1String("preferred")) {
         return new AppEntry(this, id);
-    } else if (s == QLatin1String("ktp")) {
-        return new ContactEntry(this, id);
     } else if (url.isValid() && !url.scheme().isEmpty()) {
         return new FileEntry(this, url);
     } else {
