@@ -10,7 +10,7 @@
 
 #include "ion_bbcukmetdebug.h"
 
-#include <KIO/Job>
+#include <KIO/TransferJob>
 #include <KLocalizedString>
 #include <KUnitConversion/Converter>
 
