@@ -896,6 +896,8 @@ void EnvCanadaIon::parseWindInfo(WeatherData &data, QXmlStreamReader &xml)
 void EnvCanadaIon::parseConditions(WeatherData &data, QXmlStreamReader &xml)
 {
     Q_ASSERT(xml.isStartElement() && xml.name() == QLatin1String("currentConditions"));
+
+    // Reset all the condition properties
     data.temperature = qQNaN();
     data.dewpoint = qQNaN();
     data.condition = i18n("N/A");
@@ -906,6 +908,10 @@ void EnvCanadaIon::parseConditions(WeatherData &data, QXmlStreamReader &xml)
     data.pressure = qQNaN();
     data.visibility = qQNaN();
     data.humidity = qQNaN();
+    data.windSpeed = qQNaN();
+    data.windGust = qQNaN();
+    data.windDirection = QString();
+    data.windDegrees = QString();
 
     while (!xml.atEnd()) {
         xml.readNext();
