@@ -108,7 +108,7 @@ void Surface::surface_frame(Resource *resource, uint32_t callback)
 
 bool WlCompositor::isClean()
 {
-    for (auto *surface : qAsConst(m_surfaces)) {
+    for (auto *surface : std::as_const(m_surfaces)) {
         if (!CursorRole::fromSurface(surface))
             return false;
     }
@@ -120,7 +120,7 @@ QString WlCompositor::dirtyMessage()
     if (isClean())
         return "clean";
     QStringList messages;
-    for (auto *s : qAsConst(m_surfaces)) {
+    for (auto *s : std::as_const(m_surfaces)) {
         QString role = s->m_role ? s->m_role->staticMetaObject.className() : "none/unknown";
         messages << "Surface with role: " + role;
     }
@@ -483,7 +483,7 @@ uint Keyboard::sendKey(wl_client *client, uint key, uint state)
 }
 
 // Shm implementation
-Shm::Shm(CoreCompositor *compositor, QVector<format> formats, int version)
+Shm::Shm(CoreCompositor *compositor, QList<format> formats, int version)
     : QtWaylandServer::wl_shm(compositor->m_display, version)
     , m_compositor(compositor)
     , m_formats(formats)
@@ -495,7 +495,7 @@ Shm::Shm(CoreCompositor *compositor, QVector<format> formats, int version)
 
 bool Shm::isClean()
 {
-    //    for (ShmPool *pool : qAsConst(m_pools)) {
+    //    for (ShmPool *pool : std::as_const(m_pools)) {
     //        //TODO: return false if not cursor buffer
     //        if (pool->m_buffers.isEmpty()) {
     //            return false;
