@@ -91,6 +91,8 @@ PanelView::PanelView(ShellCorona *corona, QScreen *targetScreen, QWindow *parent
     m_unhideTimer.setInterval(500ms);
     connect(&m_unhideTimer, &QTimer::timeout, this, &PanelView::restoreAutoHide);
 
+    connect(m_corona, &Plasma::Corona::editModeChanged, this, &PanelView::restoreAutoHide);
+
     m_lastScreen = targetScreen;
     connect(this, &PanelView::locationChanged, this, &PanelView::restore);
     connect(this, &PanelView::containmentChanged, this, &PanelView::refreshContainment);
@@ -888,7 +890,7 @@ void PanelView::restoreAutoHide()
         autoHide = false;
     } else if (m_containsMouse) {
         autoHide = false;
-    } else if (containment() && containment()->isUserConfiguring()) {
+    } else if (m_corona->isEditMode()) {
         autoHide = false;
     } else if (containment() && containment()->status() >= Plasma::Types::NeedsAttentionStatus && containment()->status() != Plasma::Types::HiddenStatus) {
         autoHide = false;
@@ -1189,17 +1191,6 @@ bool PanelView::event(QEvent *e)
         break;
     }
 
-    // PanelView does not take focus, but we want any users tracking focus
-    // to act like they've lost focus when the panel is clicked
-    if (e->type() == QEvent::MouseButtonPress) {
-        QWindow *focusWindow = qGuiApp->focusWindow();
-        if (focusWindow && focusWindow != this && focusWindow->flags().testFlag(Qt::FramelessWindowHint)) {
-            // postEvent takes ownership of the event
-            QFocusEvent *fe = new QFocusEvent(QEvent::FocusOut);
-            qGuiApp->postEvent(focusWindow, fe);
-        }
-    }
-
     return ContainmentView::event(e);
 }
 
